package com.TransitTrafficDailyReport;

import com.model.InternetIptransit;
import com.model.IptransitDayReport;
import com.model.TrunkDayReport;
import com.util.TimeUtil;
import com.util.TransitInfoManager;
import com.util.TransitTrafficInfoManager;
import com.util.TrunkInfoManager;
import com.util.TrunkTrafficInfoManager;
import java.math.BigDecimal;
import java.text.DecimalFormat;
import java.util.ArrayList;
import java.util.List;
import org.springframework.context.support.ClassPathXmlApplicationContext;
import org.springframework.stereotype.Component;

@Component
public class TransitTrafficReport {

   public void genTrunkDayReport(String startTime, String endTime) throws Exception {
      ClassPathXmlApplicationContext ctx = new ClassPathXmlApplicationContext("com/source/spring-config.xml");
      TrunkInfoManager trunkInfoManager = (TrunkInfoManager)ctx.getBean("trunkInfoManager");
      List tInfo = trunkInfoManager.getTrunkInfoFromMySql();
      ArrayList trunkDayReportList = new ArrayList();

      for(int i = 0; i < tInfo.size(); ++i) {
         TrunkDayReport trunkDayReport = (TrunkDayReport)tInfo.get(i);
         TrunkTrafficInfoManager trunkTrafficInfoManager = new TrunkTrafficInfoManager();
         String maxInput_bps = trunkTrafficInfoManager.getInOutMax(trunkDayReport, "cni_snmp_ifHCInOctets2bps", startTime, endTime);
         maxInput_bps = "".equals(maxInput_bps)?"0":maxInput_bps;
         String maxOutput_bps = trunkTrafficInfoManager.getInOutMax(trunkDayReport, "cni_snmp_ifHCOutOctets2bps", startTime, endTime);
         maxOutput_bps = "".equals(maxOutput_bps)?"0":maxOutput_bps;
         BigDecimal maxInput = (new BigDecimal(trunkTrafficInfoManager.bitsFormat(maxInput_bps).doubleValue())).setScale(2, 0);
         BigDecimal maxOutput = (new BigDecimal(trunkTrafficInfoManager.bitsFormat(maxOutput_bps).doubleValue())).setScale(2, 0);
         maxInput = isLessThanOne(maxInput);
         maxOutput = isLessThanOne(maxOutput);
         String avgInput_bps = trunkTrafficInfoManager.getInOutAvg(trunkDayReport, "cni_snmp_ifHCInOctets2bps", startTime, endTime);
         avgInput_bps = "".equals(avgInput_bps)?"0":avgInput_bps;
         String avgOutput_bps = trunkTrafficInfoManager.getInOutAvg(trunkDayReport, "cni_snmp_ifHCOutOctets2bps", startTime, endTime);
         avgOutput_bps = "".equals(avgOutput_bps)?"0":avgOutput_bps;
         BigDecimal avgInput = (new BigDecimal(trunkTrafficInfoManager.bitsFormat(avgInput_bps).doubleValue())).setScale(2, 0);
         BigDecimal avgOutput = (new BigDecimal(trunkTrafficInfoManager.bitsFormat(avgOutput_bps).doubleValue())).setScale(2, 0);
         avgInput = isLessThanOne(avgInput);
         avgOutput = isLessThanOne(avgOutput);
         BigDecimal maxInputU = maxInput.divide(new BigDecimal(trunkDayReport.getBandwidth()), 4, 0);
         BigDecimal maxOutputU = maxOutput.divide(new BigDecimal(trunkDayReport.getBandwidth()), 4, 0);
         BigDecimal maxInOutU = maxInputU.doubleValue() >= maxOutputU.doubleValue()?maxInputU:maxOutputU;
         new DecimalFormat("#.00");
         TrunkDayReport trunkDayReport_tmp = new TrunkDayReport();
         trunkDayReport_tmp.setTrunk_id(trunkDayReport.getTrunk_id());
         trunkDayReport_tmp.setTrunk_name(trunkDayReport.getTrunk_name());
         trunkDayReport_tmp.setBandwidth(trunkDayReport.getBandwidth());
         trunkDayReport_tmp.setInputMax_M_(maxInput.doubleValue());
         trunkDayReport_tmp.setOutputMax_M_(maxOutput.doubleValue());
         trunkDayReport_tmp.setInputAvg_M_(avgInput.doubleValue());
         trunkDayReport_tmp.setOutPutAvg_M_(avgOutput.doubleValue());
         trunkDayReport_tmp.setInputMaxUtilization(maxInputU.multiply(new BigDecimal("100")).doubleValue());
         trunkDayReport_tmp.setOutputMaxUtilization(maxOutputU.multiply(new BigDecimal("100")).doubleValue());
         trunkDayReport_tmp.setMax_InOutUtilization_(maxInOutU.multiply(new BigDecimal("100")).doubleValue());
         trunkDayReport_tmp.setCountTime(startTime);
         trunkDayReportList.add(trunkDayReport_tmp);
      }

      trunkInfoManager.setTrunkInfoToReport("trunk_day_report", trunkDayReportList);
   }

   public void genTransitDayReport(String startTime, String endTime) throws Exception {
      ClassPathXmlApplicationContext ctx = new ClassPathXmlApplicationContext("com/source/spring-config.xml");
      TransitInfoManager transitInfoManager = (TransitInfoManager)ctx.getBean("transitInfoManager");
      List tInfo = transitInfoManager.getTransitInfoFromMySql();
      ArrayList ipTransitDayReportList = new ArrayList();

      for(int i = 0; i < tInfo.size(); ++i) {
         InternetIptransit internetIptransit = (InternetIptransit)tInfo.get(i);
         TransitTrafficInfoManager transitTrafficInfoManager = new TransitTrafficInfoManager();
         String maxInput_bps = transitTrafficInfoManager.getInOutMax(internetIptransit, "cni_snmp_ifHCInOctets2bps", startTime, "");
         maxInput_bps = "".equals(maxInput_bps)?"0":maxInput_bps;
         String maxOutput_bps = transitTrafficInfoManager.getInOutMax(internetIptransit, "cni_snmp_ifHCOutOctets2bps", startTime, "");
         maxOutput_bps = "".equals(maxOutput_bps)?"0":maxOutput_bps;
         BigDecimal maxInput = (new BigDecimal(transitTrafficInfoManager.bitsFormat(maxInput_bps).doubleValue())).setScale(2, 0);
         BigDecimal maxOutput = (new BigDecimal(transitTrafficInfoManager.bitsFormat(maxOutput_bps).doubleValue())).setScale(2, 0);
         maxInput = isLessThanOne(maxInput);
         maxOutput = isLessThanOne(maxOutput);
         String avgInput_bps = transitTrafficInfoManager.getInOutAvg(internetIptransit, "cni_snmp_ifHCInOctets2bps", "", "");
         avgInput_bps = "".equals(avgInput_bps)?"0":avgInput_bps;
         String avgOutput_bps = transitTrafficInfoManager.getInOutAvg(internetIptransit, "cni_snmp_ifHCOutOctets2bps", "", "");
         avgOutput_bps = "".equals(avgOutput_bps)?"0":avgOutput_bps;
         BigDecimal avgInput = (new BigDecimal(transitTrafficInfoManager.bitsFormat(avgInput_bps).doubleValue())).setScale(2, 0);
         BigDecimal avgOutput = (new BigDecimal(transitTrafficInfoManager.bitsFormat(avgOutput_bps).doubleValue())).setScale(2, 0);
         avgInput = isLessThanOne(avgInput);
         avgOutput = isLessThanOne(avgOutput);
         BigDecimal maxInputU = maxInput.divide(new BigDecimal(internetIptransit.getBandwidthBps() / 8L / 1000L / 1000L), 4, 0);
         BigDecimal maxOutputU = maxOutput.divide(new BigDecimal(internetIptransit.getBandwidthBps() / 8L / 1000L / 1000L), 4, 0);
         BigDecimal maxInOutU = maxInputU.doubleValue() >= maxOutputU.doubleValue()?maxInputU:maxOutputU;
         new DecimalFormat("#.00");
         IptransitDayReport iptransitDayReport = new IptransitDayReport();
         iptransitDayReport.setDescription(internetIptransit.getDescription());
         iptransitDayReport.setDeviceName(internetIptransit.getDeviceName());
         iptransitDayReport.setInterfaceName(internetIptransit.getInterfaceName());
         iptransitDayReport.setBandwidth(internetIptransit.getBandwidthBps() / 8L / 1000L / 1000L);
         iptransitDayReport.setInputMax_M_(maxInput.doubleValue());
         iptransitDayReport.setOutputMax_M_(maxOutput.doubleValue());
         iptransitDayReport.setInputAvg_M_(avgInput.doubleValue());
         iptransitDayReport.setOutPutAvg_M_(avgOutput.doubleValue());
         iptransitDayReport.setInputMaxUtilization(maxInputU.multiply(new BigDecimal("100")).doubleValue());
         iptransitDayReport.setOutputMaxUtilization(maxOutputU.multiply(new BigDecimal("100")).doubleValue());
         iptransitDayReport.setMax_InOutUtilization_(maxInOutU.multiply(new BigDecimal("100")).doubleValue());
         ipTransitDayReportList.add(iptransitDayReport);
      }

      transitInfoManager.setTransitInfoToReport("iptransit_day_report", ipTransitDayReportList);
   }

   public static void main(String[] args) throws Exception {
      TransitTrafficReport tt = new TransitTrafficReport();
      String startTime = TimeUtil.lastNDay(1) + " 00:00:00";
      String endTime = TimeUtil.lastNDay(0) + " 23:59:59";

      for(int i = 1; i < 2; ++i) {
         startTime = TimeUtil.lastNDay(i) + " 00:00:00";
         endTime = TimeUtil.lastNDay(i) + " 23:59:59";
         tt.genTrunkDayReport(startTime, endTime);
         tt.genTransitDayReport(startTime, endTime);
      }

   }

   public static BigDecimal isLessThanOne(BigDecimal bigDecimal) {
      BigDecimal one = new BigDecimal(1);
      return bigDecimal.compareTo(one) < 0?one:bigDecimal;
   }
}
